# flake8: noqa

"""
    HelloSign API

    HelloSign v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by: https://openapi-generator.tech
"""


__version__ = "6.0.0-beta"

# import ApiClient
from hellosign_sdk.api_client import ApiClient

# import Configuration
from hellosign_sdk.configuration import Configuration

# import exceptions
from hellosign_sdk.exceptions import OpenApiException
from hellosign_sdk.exceptions import ApiAttributeError
from hellosign_sdk.exceptions import ApiTypeError
from hellosign_sdk.exceptions import ApiValueError
from hellosign_sdk.exceptions import ApiKeyError
from hellosign_sdk.exceptions import ApiException

from hellosign_sdk.event_callback_helper import EventCallbackHelper




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.account_api import AccountApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from hellosign_sdk.api.account_api import AccountApi
from hellosign_sdk.api.api_app_api import ApiAppApi
from hellosign_sdk.api.bulk_send_job_api import BulkSendJobApi
from hellosign_sdk.api.embedded_api import EmbeddedApi
from hellosign_sdk.api.o_auth_api import OAuthApi
from hellosign_sdk.api.report_api import ReportApi
from hellosign_sdk.api.signature_request_api import SignatureRequestApi
from hellosign_sdk.api.team_api import TeamApi
from hellosign_sdk.api.template_api import TemplateApi
from hellosign_sdk.api.unclaimed_draft_api import UnclaimedDraftApi



from hellosign_sdk.models import EventCallbackRequestEvent
import hmac
import hashlib


class EventCallbackHelper:
    @classmethod
    def is_valid(cls, api_key, event):  # noqa: E501
        """Verify that a callback came from HelloSign.com

        Args:
            api_key (string):
            event (EventCallbackRequestEvent):
        """
        hashed = hmac.new(
            bytes(api_key, 'utf-8'),
            bytes(f'{event.event_time}{event.event_type}', 'utf-8'),
            hashlib.sha256
        ).hexdigest()

        return event.event_hash == hashed
